==> kdepim-runtime-16.12.3.tar.xz: kdepim-runtime-16.12.3/resources/shared/filestore/itemfetchjob.h <==
/*  This file is part of the KDE project
    Copyright (C) 2009,2010 Kevin Krammer <kevin.krammer@gmx.at>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/

#ifndef AKONADI_FILESTORE_ITEMFETCHJOB_H
#define AKONADI_FILESTORE_ITEMFETCHJOB_H

#include "job.h"

#include <item.h>

namespace Akonadi
{
class Collection;
class ItemFetchScope;

namespace FileStore
{
class AbstractJobSession;

/**
 */
class AKONADI_FILESTORE_EXPORT ItemFetchJob : public Job
{
    friend class AbstractJobSession;

    Q_OBJECT

public:
    explicit ItemFetchJob(const Collection &collection, AbstractJobSession *session = Q_NULLPTR);

    explicit ItemFetchJob(const Item &item, AbstractJobSession *session = Q_NULLPTR);

    explicit ItemFetchJob(const Item::List &items, AbstractJobSession *session = Q_NULLPTR);

    virtual ~ItemFetchJob();

    Collection collection() const;

    Item item() const;

    Item::List requestedItems() const;

    void setFetchScope(const ItemFetchScope &fetchScope);

    ItemFetchScope &fetchScope();

    Item::List items() const;

    bool accept(Visitor *visitor) Q_DECL_OVERRIDE;

Q_SIGNALS:
    void itemsReceived(const Akonadi::Item::List &items);

private:
    void handleItemsReceived(const Akonadi::Item::List &items);

private:
    class Private;
    Private *const d;
};

}
}

#endif

==> kdepim-runtime-17.08.2.tar.xz: kdepim-runtime-17.08.2/resources/shared/filestore/itemfetchjob.h <==
/*  This file is part of the KDE project
    Copyright (C) 2009,2010 Kevin Krammer <kevin.krammer@gmx.at>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/

#ifndef AKONADI_FILESTORE_ITEMFETCHJOB_H
#define AKONADI_FILESTORE_ITEMFETCHJOB_H

#include "job.h"

#include <item.h>

namespace Akonadi
{
class Collection;
class ItemFetchScope;

namespace FileStore
{
class AbstractJobSession;

/**
 */
class AKONADI_FILESTORE_EXPORT ItemFetchJob : public Job
{
    friend class AbstractJobSession;

    Q_OBJECT

public:
    explicit ItemFetchJob(const Collection &collection, AbstractJobSession *session = nullptr);

    explicit ItemFetchJob(const Item &item, AbstractJobSession *session = nullptr);

    explicit ItemFetchJob(const Item::List &items, AbstractJobSession *session = nullptr);

    virtual ~ItemFetchJob();

    Collection collection() const;

    Item item() const;

    Item::List requestedItems() const;

    void setFetchScope(const ItemFetchScope &fetchScope);

    ItemFetchScope &fetchScope();

    Item::List items() const;

    bool accept(Visitor *visitor) override;

Q_SIGNALS:
    void itemsReceived(const Akonadi::Item::List &items);

private:
    void handleItemsReceived(const Akonadi::Item::List &items);

private:
    class Private;
    Private *const d;
};

}
}

#endif
